@@ -1076,7 +1076,8 @@ sub newreport # This function retrieves the results of interest from the texts f
             $signalnewinstance--;
           }
 
-          my ( $semaphore1, $semaphore2 );     											$line =~ s/^\s+// ;
+          my ( $semaphore1, $semaphore2 );
+          $line =~ s/^\s+// ;
 
 
           if ( -e $retfile ) #if ( not ( eval ( $skipreport ) ) )
@@ -1084,6 +1085,7 @@ sub newreport # This function retrieves the results of interest from the texts f
             open( RETFILE, "$retfile" ) or die( "$!" );
             my @lines = <RETFILE>;
             close RETFILE;
+            say $tee "TRING TO OPEN $retfile";
 
             my $countline = 0;
             my $signalhit = 0;
